Method: Translatomatic::String#parent

Defined in:
lib/translatomatic/string.rb

#parentTranslatomatic::String (readonly)

Returns If this string is a substring of another string, returns the original string. Otherwise, returns nil.

Returns:

  • (Translatomatic::String)

    If this string is a substring of another string, returns the original string. Otherwise, returns nil.



13
14
15
# File 'lib/translatomatic/string.rb', line 13

def parent
  @parent
end